@@ -585,7 +585,7 @@ get_data.MixMod <- function(x, effects = "all", component = "all", verbose = TRU
       fitfram_zi_re <- stats::model.frame(x, type = "zi_random")
 
       if (!is_empty_object(fitfram_re)) {
-        for (i in 1:length(fitfram_re)) {
+        for (i in seq_along(fitfram_re)) {
           fitfram <- .merge_dataframes(fitfram_re[[i]], fitfram, replace = TRUE)
         }
       }
@@ -593,7 +593,7 @@ get_data.MixMod <- function(x, effects = "all", component = "all", verbose = TRU
         fitfram <- .merge_dataframes(fitfram_zi, fitfram, replace = TRUE)
       }
       if (!is_empty_object(fitfram_zi_re)) {
-        for (i in 1:length(fitfram_zi_re)) {
+        for (i in seq_along(fitfram_zi_re)) {
           fitfram <- .merge_dataframes(fitfram_zi_re[[i]], fitfram, replace = TRUE)
         }
       }
