@@ -14,7 +14,7 @@
 #' @export
 get_predictors <- function(x, verbose = TRUE) {
   vars <- if (inherits(x, "wbm")) {
-    unlist(.compact_list(find_terms(x, flatten = FALSE)[c("conditional", "instruments")]))
+    unlist(compact_list(find_terms(x, flatten = FALSE)[c("conditional", "instruments")]))
   } else {
     find_predictors(x, effects = "fixed", component = "all", flatten = TRUE)
   }
@@ -22,7 +22,7 @@ get_predictors <- function(x, verbose = TRUE) {
   dat <- get_data(x)
   dat <- dat[, intersect(vars, colnames(dat)), drop = FALSE]
 
-  if (.is_empty_object(dat)) {
+  if (is_empty_object(dat)) {
     if (isTRUE(verbose)) {
       warning(format_message("Data frame is empty, probably you have an intercept-only model?"), call. = FALSE)
     }
