@@ -19,19 +19,53 @@
 #' }
 #' @export
 null_model <- function(model, verbose = TRUE, ...) {
+  offset_term <- tryCatch(
+    {
+      f <- safe_deparse(find_formula(model)$conditional)
+      if (grepl("offset(", f, fixed = TRUE)) {
+        out <- gsub("(.*)offset\\((.*)\\)(.*)", "\\2", f)
+      } else {
+        out <- NULL
+      }
+      out
+    },
+    error = function(e) {
+      NULL
+    }
+  )
+
   if (is_mixed_model(model)) {
-    .null_model_mixed(model, verbose)
+    .null_model_mixed(model, offset_term, verbose)
   } else if (inherits(model, "clm2")) {
     stats::update(model, location = ~1, scale = ~1)
   } else if (inherits(model, "multinom")) {
     stats::update(model, ~1, trace = FALSE)
   } else {
-    stats::update(model, ~1, ...)
+    if (!is.null(offset_term)) {
+      tryCatch(
+        {
+          do.call(stats::update, list(model, ~1, offset = .str2lang(offset_term)))
+        },
+        error = function(e) {
+          if (verbose) {
+            warning(format_message(
+              "Model contains offset-terms, which could not be considered in the returned null-model.",
+              "Coefficients might be inaccurate."
+            ), call. = FALSE)
+          }
+          stats::update(model, ~1)
+        }
+      )
+    } else {
+      # stats::update(model, ~1)
+      out <- stats::update(model, ~1, evaluate = FALSE)
+      eval(out, envir = parent.frame())
+    }
   }
 }
 
 
-.null_model_mixed <- function(model, verbose = TRUE) {
+.null_model_mixed <- function(model, offset_term = NULL, verbose = TRUE) {
   if (inherits(model, "MixMod")) {
     nullform <- stats::as.formula(paste(find_response(model), "~ 1"))
     null.model <- stats::update(model, fixed = nullform)
@@ -45,7 +79,11 @@ null_model <- function(model, verbose = TRUE, ...) {
     nullform <- stats::reformulate(re.terms, response = resp)
     null.model <- tryCatch(
       {
-        stats::update(model, nullform)
+        if (!is.null(offset_term)) {
+          do.call(stats::update, list(model, formula = nullform, offset = .str2lang(offset_term)))
+        } else {
+          stats::update(model, nullform)
+        }
       },
       error = function(e) {
         msg <- e$message
