@@ -126,6 +126,7 @@ standardize_names.parameters_distribution <- standardize_names.parameters_model
   cn[cn == "conf.low"]     <- "CI_low"
   cn[cn == "conf.high"]    <- "CI_high"
   cn[cn == "conf.level"]   <- "CI"
+  cn[cn == "conf.method"]  <- "CI_method"
   cn[cn == "n.obs"]        <- "n_Obs"
   cn[cn == "n"]            <- "n_Obs"
   cn[cn == "type"]         <- "Type"
@@ -164,6 +165,7 @@ standardize_names.parameters_distribution <- standardize_names.parameters_model
   cn[cn == "CI"]             <- "conf.level"
   cn[cn == "df_error"]       <- "df.error"
   cn[cn == "df_residual"]    <- "df.residual"
+  cn[cn == "CI_method"]      <- "conf.method"
   cn[cn == "n_Obs"]          <- "n.obs"
   cn[cn == "n"]              <- "n.obs"
   cn[cn == "n_Missing"]      <- "missing.obs"
