@@ -196,7 +196,7 @@ if (.runThisTest) {
 
     test_that("get_predicted", {
       tmp <- mgcv::gam(y ~ s(x0) + s(x1), data = head(dat, 30))
-      pred <- get_predicted(tmp, verbose = FALSE)
+      pred <- get_predicted(tmp, verbose = FALSE, ci = .95)
       expect_s3_class(pred, "get_predicted")
       expect_equal(
         as.vector(pred),
@@ -210,19 +210,66 @@ if (.runThisTest) {
         tolerance = 1e-3
       )
 
-      x <- get_predicted(tmp, predict = NULL, type = "link")
-      y <- get_predicted(tmp, predict = "link")
+      x <- get_predicted(tmp, predict = NULL, type = "link", ci = .95)
+      y <- get_predicted(tmp, predict = "link", ci = .95)
       z <- predict(tmp, type = "link", se.fit = TRUE)
       expect_equal(x, y)
       expect_equal(x, z$fit, ignore_attr = TRUE)
       expect_equal(as.data.frame(x)$SE, z$se.fit, ignore_attr = TRUE)
 
-      x <- get_predicted(tmp, predict = NULL, type = "response", verbose = FALSE)
-      y <- get_predicted(tmp, predict = "expectation")
+      x <- get_predicted(tmp, predict = NULL, type = "response", verbose = FALSE, ci = .95)
+      y <- get_predicted(tmp, predict = "expectation", ci = .95)
       z <- predict(tmp, type = "response", se.fit = TRUE)
       expect_equal(x, y, ignore_attr = TRUE)
       expect_equal(x, z$fit, ignore_attr = TRUE)
       expect_equal(as.data.frame(x)$SE, z$se.fit, ignore_attr = TRUE)
+
+      # poisson
+      void <- capture.output(
+        dat <- gamSim(1, n = 400, dist = "poisson", scale = .25)
+      )
+      b4 <- gam(
+        y ~ s(x0) + s(x1) + s(x2) + s(x3),
+        family = poisson,
+        data = dat,
+        method = "GACV.Cp",
+        scale = -1
+      )
+      d <- get_datagrid(b4, at = "x1")
+      p1 <- get_predicted(b4, data = d, predict = "expectation", ci = .95)
+      p2 <- predict(b4, newdata = d, type = "response")
+      expect_equal(as.vector(p1), as.vector(p2), tolerance = 1e-4, ignore_attr = TRUE)
+
+      p1 <- get_predicted(b4, data = d, predict = "link", ci = .95)
+      p2 <- predict(b4, newdata = d, type = "link")
+      expect_equal(as.vector(p1), as.vector(p2), tolerance = 1e-4, ignore_attr = TRUE)
+
+      p1 <- get_predicted(b4, data = d, type = "link", predict = NULL, ci = .95)
+      p2 <- predict(b4, newdata = d, type = "link")
+      expect_equal(as.vector(p1), as.vector(p2), tolerance = 1e-4, ignore_attr = TRUE)
+
+      p1 <- get_predicted(b4, data = d, type = "response", predict = NULL, ci = .95)
+      p2 <- predict(b4, newdata = d, type = "response")
+      expect_equal(as.vector(p1), as.vector(p2), tolerance = 1e-4, ignore_attr = TRUE)
+
+      void <- capture.output(
+        dat <- gamSim(1, n = 400, dist = "poisson", scale = .25)
+      )
+      b4 <- gam(
+        y ~ s(x0) + s(x1) + s(x2) + s(x3),
+        family = poisson,
+        data = dat,
+        method = "GACV.Cp",
+        scale = -1
+      )
+
+      # exclude argument should be pushed through ...
+      p1 <- predict(b4, type = "response", exclude = "s(x1)")
+      p2 <- get_predicted(b4, predict = "expectation", exclude = "s(x1)", ci = .95)
+      expect_equal(as.vector(p1), as.vector(p2), tolerance = 1e-4, ignore_attr = TRUE)
+      p1 <- predict(b4, type = "link", exclude = "s(x1)")
+      p2 <- get_predicted(b4, predict = "link", exclude = "s(x1)", ci = .95)
+      expect_equal(as.vector(p1), as.vector(p2), tolerance = 1e-4, ignore_attr = TRUE)
     })
   }
 }
