@@ -52,9 +52,9 @@ if (.runThisTest &&
 
   test_that("find_offset", {
     data(mtcars)
-    model_off <- lmer(log(mpg) ~ disp + (1|cyl), offset = log(wt), data = mtcars)
+    model_off <- lmer(log(mpg) ~ disp + (1 | cyl), offset = log(wt), data = mtcars)
     expect_identical(find_offset(model_off), "wt")
-    model_off <- lmer(log(mpg) ~ disp + (1|cyl) + offset(log(wt)), data = mtcars)
+    model_off <- lmer(log(mpg) ~ disp + (1 | cyl) + offset(log(wt)), data = mtcars)
     expect_identical(find_offset(model_off), "wt")
   })
 
@@ -449,24 +449,26 @@ if (.runThisTest &&
     v2 <- as.matrix(vcovAdj(m2))
     expect_equal(v1, v2)
 
-    p1 <- get_predicted(m2, ci_method = "satterthwaite")
+    p1 <- get_predicted(m2, ci_method = "satterthwaite", ci = .95)
     p1 <- data.frame(p1)
     em1 <- ref_grid(
       object = m2,
-      specs = ~ Days,
+      specs = ~Days,
       at = list(Days = sleepstudy$Days),
-      lmer.df = "satterthwaite")
+      lmer.df = "satterthwaite"
+    )
     em1 <- confint(em1)
     expect_equal(p1$CI_low, em1$lower.CL)
     expect_equal(p1$CI_high, em1$upper.CL)
 
-    p2 <- get_predicted(m2, ci_method = "kenward-roger")
+    p2 <- get_predicted(m2, ci_method = "kenward-roger", ci = .95)
     p2 <- data.frame(p2)
     em2 <- ref_grid(
       object = m2,
-      specs = ~ Days,
+      specs = ~Days,
       at = list(Days = sleepstudy$Days),
-      lmer.df = "kenward-roger")
+      lmer.df = "kenward-roger"
+    )
     em2 <- confint(em2)
     expect_equal(p2$CI_low, em2$lower.CL)
     expect_equal(p2$CI_high, em2$upper.CL)
@@ -490,7 +492,7 @@ if (.runThisTest &&
     newdata <- ChickWeight[ChickWeight$Time %in% 0:10 & ChickWeight$Chick %in% c(1, 40), ]
     newdata$Chick[newdata$Chick == "1"] <- NA
     expect_equal(
-      head(as.data.frame(get_predicted(mod, data = newdata, include_random = FALSE))),
+      head(as.data.frame(get_predicted(mod, data = newdata, include_random = FALSE, ci = .95))),
       data.frame(
         Predicted = c(37.53433, 47.95719, 58.78866, 70.02873, 81.67742, 93.73472),
         SE = c(1.68687, 0.82574, 1.52747, 2.56109, 3.61936, 4.76178),
