@@ -1,6 +1,9 @@
+skip_if_not(getRversion() >= "4.2.0")
+
 if (requiet("testthat") &&
   requiet("insight") &&
-  requiet("quantreg")) {
+  requiet("quantreg") &&
+  getRversion() >= "4.2.0") {
   data(stackloss)
   m1 <-
     rq(stack.loss ~ Air.Flow + Water.Temp,
